#!/bin/env python3
#
# This wrapper works around fontmake's limitation (at the time of this writing)
# of not being able to specify the output directory for the generated font
# binaries. The Meson build system's custom target function has fixed
# expectations about where files must show up. Also, autohint the binaries
# while we're at it.

from pathlib import Path
import argparse
import subprocess


parser = argparse.ArgumentParser()
parser.add_argument("fontmake", type=str, help="The path to fontmake.")
parser.add_argument("psautohint", type=str, help="The path to psautohint.")
parser.add_argument("font_source", help="The path to the font source.")
parser.add_argument("output_dir", help="The full target output path.")
args = parser.parse_args()

source = Path(args.font_source).resolve()
output_dir = Path(args.output_dir)

subprocess.run([
    args.fontmake, "-g", source, "-i", "-o", "otf", "--verbose",
    "WARNING"
], cwd=output_dir)

for otf in (output_dir / "instance_otf").glob("*.otf"):
    subprocess.run([args.psautohint, "-qq", str(otf)])
    output_dir.mkdir(exist_ok=True)
    otf.rename(output_dir / otf.name)



# This is the configuration for HT Letterspacer.
#
# Reference:
# Script, Category, Subcategory, value, referenceGlyph, filter

# Letters
*,Letter,Uppercase,1.25,H,*,
*,Letter,Smallcaps,1.1,h.sc,*,
*,Letter,Lowercase,1,x,*,
*,Letter,Lowercase,0.7,m.sups,.sups,

# Numbers
*,Number,Decimal Digit,1.2,one,*,
*,Number,Decimal Digit,1.2,zero.osf,.osf,
*,Number,Fraction,1.3,*,*,
*,Number,*,0.9,*,.dnom,
*,Number,*,0.9,*,.numr,
*,Number,*,0.9,*,.inferior,
*,Number,*,0.9,*,superior,

# Punctuation
*,Punctuation,Other,1,*,*,
*,Punctuation,Parenthesis,1.2,*,*,
*,Punctuation,Quote,1.2,*,*,
*,Punctuation,Dash,1,*,*,
*,Punctuation,*,1,*,slash,
*,Punctuation,*,1.2,*,*,

# Symbols
*,Symbol,Currency,1.6,*,*,
*,Symbol,*,1.5,*,*,
*,Mark,*,1,*,*,

# Devanagari
devanagari,Letter,Other,1,devaHeight,*,
devanagari,Letter,Ligature,1,devaHeight,*,
